<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Sovelluksen välityspalvelin</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy tyyppi</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP osoite</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Portti</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjätunnus</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Valinnainen</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Tarkista &quot;käytä välityspalvelinta&quot; sovelluksessa. Löytyy pikavalikosta määritysten jälkeen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Virheellinen IP-osoite</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Virheellinen portti</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Katkaise</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Yhdistää</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Katkaise</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Haluatko varmasti poistaa tämän määrityksen?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Verkkokaapeli %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Tukiasema</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE yhteys %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Uusi VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN tyyppi</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>Avoinyhteys</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>VPN-vahvuus</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Vie</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Verkko</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Sovelluksen välityspalvelin</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Jaettu tukiasema</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Verkkon tiedot</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Välityspalvelin</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Kaapeli</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Langaton verkko</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Lentotila</translation>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Verkkokortti</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Lisää verkkoyhteys</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Langaton verkkokortti</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Yhdistä piilotettuun verkkoon</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Luo PPPoE yhteys</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN tila</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Luo VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Tuo VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy tyyppi</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Kokoonpanon URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP osoite</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Portti</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjänimi</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Tukiasema</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Luo tukiasema</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Liitäntä</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Taajuusalue</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Yhdyskäytävä</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Ensisijainen DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Verkkopeite</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Etuliite</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Nopeus</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Lentotila</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Lentotilan käyttöönotto sammuttaa langattoman verkon, jaetun tukiaseman ja Bluetoothin</translation>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Virheellinen DNS-osoite</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Verkko</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Ei sido</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>MAC-osoite</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Kloonattu MAC</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Muokkaa MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Yleinen</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Yleinen</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Nimi on jo olemassa</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Automaattinen yhteys</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Tukiasema</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Lisää asetukset</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Luo tukiasema</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP osoite</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Yhdyskäytävä</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Päällekkäinen IP-osoite</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Virheellinen IP-osoite</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Virheellinen verkkomaski</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Vain yksi yhdyskäytävä on sallittu</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Virheellinen yhdyskäytävä</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Verkkopeite</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Päällekkäinen IP-osoite</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Virheellinen IP-osoite</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Vain yksi yhdyskäytävä on sallittu</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Virheellinen yhdyskäytävä</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Etuliite</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automaattinen</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuaalinen</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ohita</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP osoite</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Yhdyskäytävä</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Sovelletaan vain vastaaviin resursseihin</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Menetelmä</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Verkkopeite</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Etuliite</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Virheellinen IP-osoite</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Virheellinen verkkomaski</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Virheellinen yhdyskäytävä</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Verkko</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP ristiriita</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Menetelmä</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automaattinen</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuaalinen</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ohita</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Verkkon tiedot</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Välityspalvelin</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Sovelluksen välityspalvelin</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Lentotila</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Verkkon tiedot</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Verkko</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP ristiriita</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Suljettu</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuaalinen</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automaattinen</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Määritä verkkohallinnassa</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Jaettu tukiasema</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjätunnus</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Palvelu</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Hylkää EAP-todennus</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Hylkää PAP-todennus</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Hylkää CHAP-todennus</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Hylkää MSCHAP-todennus</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Hylkää MSCHAPv2-todennus</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Ei BSD-pakkausta</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Ei tyhjää tiedon pakkausta</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Ei TCP-otsakkeiden pakkausta</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Ei protokollakentän pakkausta</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Ei osoiteen/ohjauksen pakkausta</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Lähetä PPP echo-paketteja</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Käytä MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bittinen MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Tilaobjekti MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Luo PPPoE yhteys</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Välityspalvelin</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy tyyppi</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuaalinen</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automaattinen</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Valinnainen</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Portti</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP välityspalvelin</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS välityspalvelin</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP välityspalvelin</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS välityspalvelin</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ohita yllä mainittujen isäntien ja toimialueiden välityspalvelin määritykset</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Kokoonpanon URL</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Tietoturva</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunneloitu TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Suojattu EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Tallenna salasana tälle käyttäjälle</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Tallenna salasana kaikille käyttäjille</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Kysy minulta aina</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Suljettu</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Nimetön</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Varmistettu</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Molemmat</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automaattinen</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versio 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versio 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Suojattu EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identiteetti</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Salasanan valinnat</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Yksityinen avain</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA varmenne</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Käyttäjän varmenne</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonyymi tunnus</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Valmistelu</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC tiedosto</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Sisäinen todennus</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP versio</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Yksityinen salasana</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Virheellinen salasana</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Mitään</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Tietoturva</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Avain</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Suojaus vaaditaan</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Virheellinen salasana</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Mitään</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 liikeyritys</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Jaettu avain</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Avaa järjestelmä</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Tietoturva</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Todennus</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Avain</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN lisäasetukset</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Muokkaa yhdyskäytävän porttia</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Yhdyskäytävän portti</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Mukauta neuvotteluväli</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Uudelleenneuvottelu</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Käytä LZO pakkausta</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Käytä TCP-yhteyttä</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Käytä TAP-laitetta</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Mukauta tunnelin MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Mukauta UDP-fragmentin kokoa</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP-fragmentin koko</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Rajoita tunnelin TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Satunnainen etäisäntä</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN lisäasetukset</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (oletus)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Verkkonäyttö</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Suojattu (oletus)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Heikko</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Mitään</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T kun saatavilla (oletus)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T aina</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Suljettu</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH-ryhmä 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH-ryhmä 2 (oletus)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH-ryhmä 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Palvelin (oletus)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH-ryhmä 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Toimialue</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Toimittaja</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versio</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Salaus</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT -muuntotila</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH ryhmä</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Välitä salassapito</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Paikallinen portti</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Poista käytöstä poistuneiden tunnistus</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>IPsec käyttöön</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Ryhmän nimi</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Ryhmän tunnus</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Jaettu avain</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Phase1 -algoritmit</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Vaihe2 -algoritmit</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Virheellinen yhdyskäytävä</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Yhdyskäytävä</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA varmenne</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Välityspalvelin</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Salli Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD Script</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Käyttäjän varmenne</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Yksityinen avain</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Käytä FSID-tunnusta avaimena</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Virheellinen yhdyskäytävä</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Sertifikaatit (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Varmenteet salasanalla (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Staattinen avain</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Tallennettu</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Kysy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Ei vaadita</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Yhdyskäytävä</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tunnistautumistapa</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA varmenne</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Käyttäjän varmenne</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Yksityinen avain</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Salasanan valinnat</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Yksityinen salasana</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjätunnus</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Määritä avaimen suunta</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Avaimen suunta</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Ulkoinen IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Paikallinen IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Kaikki käytettävissä (oletus)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (vähemmän turvallinen)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (turvallisin)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Hylkää EAP-todennus</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Hylkää PAP-todennus</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Hylkää CHAP-todennus</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Hylkää MSCHAP-todennus</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Hylkää MSCHAPv2-todennus</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Ei BSD-pakkausta</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Ei tyhjää tiedon pakkausta</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Ei TCP-otsakkeiden pakkausta</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Ei protokollakentän pakkausta</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Ei osoiteen/ohjauksen pakkausta</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Lähetä PPP echo-paketteja</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Käytä MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Tietoturva</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Tilaobjekti MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN tila</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Luo VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Tuo VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Tuontivirhe</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Tiedoston virhe</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN välityspalvelin</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Ei vaadita</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy tyyppi</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Palvelimen IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Portti</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Yritä uudelleen virheen sattuessa</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjätunnus</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>Varmennetiedosto</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Ohita varmenne varoitukset</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Käytä TLS-isäntänimen laajennuksia</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN-suojaus</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>oletus</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Mitään</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Salakirjoitus</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC tunnistus</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Virheellinen yhdyskäytävä</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Tallennettu</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Kysy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Ei vaadita</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Yhdyskäytävä</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjätunnus</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Salasanan valinnat</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT-toimialue</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN välityspalvelin</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Palvelimen IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Portti</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjätunnus</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Virheellinen yhdyskäytävä</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Yksityinen avain</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH-agentti</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Älykortti</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Jaettu avain</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Yhdyskäytävä</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA varmenne</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tunnistautumistapa</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Käyttäjän varmenne</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjätunnus</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Pyydä sisäinen IP-osoite</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Pakota UDP-kapselointi</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Käytä IP-pakkausta</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Ota mukautetut salauslausekkeet käyttöön</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS tunnistus</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>oletus</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Asiakas</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Palvelin</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Kohde täsmää</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Ulkoisen varmenteen tyyppi</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Avaintiedosto</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Määritä avaimen suunta</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Avaimen suunta</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Virheellinen yhdyskäytävä</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Tallennettu</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Kysy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Ei vaadita</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Yhdyskäytävä</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjätunnus</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Salasanan valinnat</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Ryhmän nimi</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Ryhmän salasana</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Käytä hybriditodennusta</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Varmennetiedosto</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Kytke ensin verkkokaapeli</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Verkkokortti</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Lisää verkkoyhteys</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Valitse asetukset</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Langaton verkkokortti</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Sulje tukiasema</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Poista esin tukiaseman jakaminen, jos haluat yhteyden langattomaan verkkoon</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Yhdistä piilotettuun verkkoon</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Ei sido</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>MAC-osoite</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Muokkaa MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Tukiasema</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokolla</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Suojaustyyppi</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanava</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Taajuusalue</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Liitäntä</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Verkkopeite</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Yhdyskäytävä</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Ensisijainen DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Etuliite</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Nopeus</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Laite suljettu</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Yhdistetty, mutta ei internet osoitetta</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ei yhteyttä</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Verkkokaapeli irrotettu</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Yhdistää</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Todennus</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Hakee IP osoitetta</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Yhdistetty</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Katkaistu</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP ristiriita</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Epäonnistui</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Osoitteen haku</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Kiinteä verkko</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Kaapeli %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Langaton verkko</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Langaton verkko: %1</translation>
    </message>
</context>
</TS>